bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.random
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.random